#ifndef __IUP_BI
#define __IUP_BI

/'* \file
 * \brief User API
 * IUP - A Portable User Interface Toolkit
 * Tecgraf: Computer Graphics Technology Group, PUC-Rio, Brazil
 * http://www.tecgraf.puc-rio.br/iup  mailto:iup@tecgraf.puc-rio.br
 *
 * See Copyright Notice at the end of this file
 '/


#include once "iupkey.bi"
#include once "iupdef.bi"

#ifdef __FB_WIN32__

#inclib "user32"
#inclib "gdi32"
#inclib "comdlg32"
#inclib "comctl32"
#inclib "shell32"
#inclib "advapi32"
#inclib "uuid"
#inclib "ole32"
#inclib "imm32"

#libpath "lib/win32"

#else
#libpath "lib/linux"
#endif




#define IUP_NAME "IUP - Portable User Interface"
#define IUP_COPYRIGHT  "Copyright (C) 1994-2014 Tecgraf, PUC-Rio."
#define IUP_DESCRIPTION "Multi-platform toolkit for building graphical user interfaces."
#define IUP_VERSION "3.11"         /' bug fixes are reported only by IupVersion functions '/
#define IUP_VERSION_NUMBER 311000
#define IUP_VERSION_DATE "2014/07/28"  /' does not include bug fix releases '/

type Ihandle
  as integer dummy
end type

type Icallback as function cdecl (byval as Ihandle ptr) as integer

extern "C" lib "iup"

/'**********************************************************************'/
/'                        Main API                                      '/
/'**********************************************************************'/

declare function IupOpen          (byval argc as integer ptr, byval argv as zstring ptr ptr ptr) as integer
declare sub      IupClose
declare sub      IupImageLibOpen

declare function IupMainLoop       as integer
declare function IupLoopStep       as integer
declare function IupLoopStepWait   as integer
declare function IupMainLoopLevel  as integer
declare sub      IupFlush         
declare sub      IupExitLoop      

declare function IupRecordInput(byval filename as const zstring ptr, byval mode as integer) as integer
declare function IupPlayInput(byval filename as const zstring ptr) as integer

declare sub      IupUpdate        (byval as Ihandle ptr)
declare sub      IupUpdateChildren(byval as Ihandle ptr)
declare sub      IupRedraw        (byval as Ihandle ptr, byval children as integer)
declare sub      IupRefresh       (byval as Ihandle ptr)
declare sub      IupRefreshChildren(byval as Ihandle ptr)

declare function IupHelp          (byval url as const zstring ptr) as integer
declare function IupLoad          (byval filename as const zstring ptr) as zstring ptr
declare function IupLoadBuffer    (byval buffer as const zstring ptr) as zstring ptr

declare function IupVersion as zstring ptr
declare function IupVersionDate as zstring ptr
declare function IupVersionNumber as integer

declare sub      IupSetLanguage   (byval lng as const zstring ptr)
declare function IupGetLanguage as zstring ptr
declare sub      IupSetLanguageString(byval name as const zstring ptr, byval str as const zstring ptr)
declare sub      IupStoreLanguageString(byval name as const zstring ptr, byval str as const zstring ptr)
declare function IupGetLanguageString(byval name as const zstring ptr) as zstring ptr
declare sub      IupSetLanguagePack(byval as Ihandle ptr)

declare sub      IupDestroy      (byval as Ihandle ptr)
declare sub      IupDetach       (byval child as Ihandle ptr)
declare function IupAppend       (byval as Ihandle ptr,byval child as Ihandle ptr) as Ihandle ptr
declare function IupInsert       (byval as Ihandle ptr, byval ref_child as Ihandle ptr, byval child as Ihandle ptr) as Ihandle ptr
declare function IupGetChild     (byval as Ihandle ptr, byval pos as integer) as Ihandle ptr
declare function IupGetChildPos  (byval as Ihandle ptr, byval child as Ihandle ptr) as integer
declare function IupGetChildCount(byval as Ihandle ptr) as integer
declare function IupGetNextChild (byval as Ihandle ptr, byval child as Ihandle ptr) as Ihandle ptr
declare function IupGetBrother   (byval as Ihandle ptr) as Ihandle ptr
declare function IupGetParent    (byval as Ihandle ptr) as Ihandle ptr
declare function IupGetDialog    (byval as Ihandle ptr) as Ihandle ptr
declare function IupGetDialogChild(byval as Ihandle ptr, byval name as const zstring ptr) as Ihandle ptr
declare function IupReparent     (byval as Ihandle ptr, byval new_parent as Ihandle ptr, byval ref_child as Ihandle ptr) as integer

declare function IupPopup         (byval as Ihandle ptr, byval x as integer, byval y as integer) as integer
declare function IupShow          (byval as Ihandle ptr) as integer
declare function IupShowXY        (byval as Ihandle ptr, byval x as integer, byval y as integer) as integer
declare function IupHide          (byval as Ihandle ptr) as integer
declare function IupMap           (byval as Ihandle ptr) as integer
declare sub      IupUnmap         (byval as Ihandle ptr)

declare sub      IupResetAttribute(byval as Ihandle ptr, byval name as const zstring ptr)
declare function IupGetAllAttributes(byval as Ihandle ptr, byval names as zstring ptr ptr, byval n as integer) as integer
declare function IupSetAtt(byval handle_name as const zstring ptr, byval as Ihandle ptr, byval name as const zstring ptr, ...) as Ihandle ptr
declare function IupSetAttributes (byval as Ihandle ptr, byval str as const zstring ptr) as Ihandle ptr
declare function IupGetAttributes (byval as Ihandle ptr) as zstring ptr

declare sub      IupSetAttribute   (byval as Ihandle ptr, byval name as const zstring ptr, byval value as const zstring ptr)
declare sub      IupSetStrAttribute(byval as Ihandle ptr, byval name as const zstring ptr, byval value as const zstring ptr)
declare sub      IupSetStrf        (byval as Ihandle ptr, byval name as const zstring ptr, byval format as const zstring ptr, ...)
declare sub      IupSetInt         (byval as Ihandle ptr, byval name as const zstring ptr, byval value as integer)
declare sub      IupSetFloat       (byval as Ihandle ptr, byval name as const zstring ptr, byval value as single)
declare sub      IupSetRGB         (byval as Ihandle ptr, byval name as const zstring ptr, byval r as ubyte, byval g as ubyte, byval b as ubyte)

declare function IupGetAttribute(byval as Ihandle ptr, byval name as const zstring ptr) as zstring ptr
declare function IupGetInt      (byval as Ihandle ptr, byval name as const zstring ptr) as integer
declare function IupGetInt2     (byval as Ihandle ptr, byval name as const zstring ptr) as integer
declare function IupGetIntInt   (byval as Ihandle ptr, byval name as const zstring ptr, byval i1 as integer ptr, byval i2 as integer ptr) as integer
declare function IupGetFloat    (byval as Ihandle ptr, byval name as const zstring ptr) as single
declare sub      IupGetRGB      (byval as Ihandle ptr, byval name as const zstring ptr, byval r as ubyte ptr, byval g as ubyte ptr, byval b as ubyte ptr)

declare sub      IupSetAttributeId(byval as Ihandle ptr, byval name as const zstring ptr, byval id as integer, byval value as const zstring ptr)
declare sub      IupSetStrAttributeId(byval as Ihandle ptr, byval name as const zstring ptr, byval id as integer, byval value as const zstring ptr)
declare sub      IupSetStrfId(byval as Ihandle ptr, byval name as const zstring ptr,byval id as integer, byval format as const zstring ptr, ...)
declare sub      IupSetIntId(byval as Ihandle ptr, byval name as const zstring ptr, byval id as integer, byval value as integer)
declare sub      IupSetFloatId(byval as Ihandle ptr, byval name as const zstring ptr, byval id as integer, byval value as single)
declare sub      IupSetRGBId(byval as Ihandle ptr, byval name as const zstring ptr,byval id as integer, byval r as ubyte, byval g as ubyte, byval b as ubyte)

declare function IupGetAttributeId(byval as Ihandle ptr, byval name as const zstring ptr, byval id as integer) as zstring ptr
declare function IupGetIntId(byval as Ihandle ptr, byval name as const zstring ptr, byval id as integer) as integer
declare function IupGetFloatId(byval as Ihandle ptr, byval name as const zstring ptr, byval id as integer) as single
declare sub      IupGetRGBId(byval as Ihandle ptr, byval name as const zstring ptr,byval id as integer, byval r as ubyte ptr, byval g as ubyte ptr, byval b as ubyte ptr)

declare sub      IupSetAttributeId2(byval as Ihandle ptr, byval name as const zstring ptr, byval lin as integer, byval col as integer, byval value as const zstring ptr)
declare sub      IupSetStrAttributeId2(byval as Ihandle ptr, byval name as const zstring ptr, byval lin as integer, byval col as integer, byval value as const zstring ptr)
declare sub      IupSetStrfId2(byval as Ihandle ptr, byval name as const zstring ptr,  byval lin as integer, byval col as integer, byval format as const zstring ptr, ...)
declare sub      IupSetIntId2(byval as Ihandle ptr, byval name as const zstring ptr, byval lin as integer, byval col as integer, byval value as integer)
declare sub      IupSetFloatId2(byval as Ihandle ptr, byval name as const zstring ptr, byval lin as integer, byval col as integer, byval value as single)
declare sub      IupSetRGBId2(byval as Ihandle ptr, byval name as const zstring ptr, byval lin as integer, byval col as integer, byval r as ubyte, byval g as ubyte, byval b as ubyte)

declare function IupGetAttributeId2(byval as Ihandle ptr, byval name as const zstring ptr, byval lin as integer, byval col as integer) as zstring ptr
declare function IupGetIntId2(byval as Ihandle ptr, byval name as const zstring ptr, byval lin as integer, byval col as integer) as integer
declare function IupGetFloatId2(byval as Ihandle ptr, byval name as const zstring ptr, byval lin as integer, byval col as integer) as single
declare sub      IupGetRGBId2(byval as Ihandle ptr, byval name as const zstring ptr, byval lin as integer, byval col as integer, byval r as ubyte ptr, byval g as ubyte ptr, byval b as ubyte ptr)

declare sub      IupSetGlobal  (byval name as const zstring ptr, byval value as const zstring ptr)
declare sub      IupSetStrGlobal(byval name as const zstring ptr, byval value as const zstring ptr)
declare function IupGetGlobal  (byval name as const zstring ptr) as zstring ptr

declare function IupSetFocus     (byval as Ihandle ptr) as Ihandle ptr
declare function IupGetFocus     as Ihandle ptr
declare function IupPreviousField(byval as Ihandle ptr) as Ihandle ptr
declare function IupNextField    (byval as Ihandle ptr) as Ihandle ptr

declare function IupGetCallback (byval as Ihandle ptr, byval name as const zstring ptr) as Icallback
declare function IupSetCallback (byval as Ihandle ptr, byval name as const zstring ptr, byval func as Icallback) as Icallback
declare function IupSetCallbacks(byval as Ihandle ptr, byval name as const zstring ptr, byval func as Icallback, ...) as Ihandle ptr

declare function IupGetFunction(byval name as const zstring ptr) as Icallback
declare function IupSetFunction(byval name as const zstring ptr, func as Icallback) as Icallback

declare function IupGetHandle    (byval name as const zstring ptr) as Ihandle ptr
declare function IupSetHandle    (byval name as const zstring ptr, byval as Ihandle ptr) as Ihandle ptr
declare function IupGetAllNames  (byval names as const zstring ptr ptr, byval n as integer) as integer
declare function IupGetAllDialogs(byval names as const zstring ptr ptr, byval n as integer) as integer
declare function IupGetName      (byval as Ihandle ptr) as zstring ptr

declare sub      IupSetAttributeHandle(byval as Ihandle ptr, byval name as const zstring ptr, byval ih_named as Ihandle ptr)
declare function IupGetAttributeHandle(byval as Ihandle ptr, byval name as const zstring ptr) as Ihandle ptr

declare function IupGetClassName(byval as Ihandle ptr) as zstring ptr
declare function IupGetClassType(byval as Ihandle ptr) as zstring ptr
declare function IupGetAllClasses(byval names as const zstring ptr ptr, byval n as integer) as integer
declare function IupGetClassAttributes(byval classname as const zstring ptr, byval names as const zstring ptr ptr, byval n as integer) as integer
declare function IupGetClassCallbacks(byval classname as const zstring ptr, byval names as const zstring ptr ptr, byval n as integer) as integer
declare sub      IupSaveClassAttributes(byval as Ihandle ptr)
declare sub      IupCopyClassAttributes(byval src_ih as Ihandle ptr, byval dst_ih as Ihandle ptr)
declare sub      IupSetClassDefaultAttribute(byval classname as const zstring ptr, byval name as const zstring ptr, byval value as const zstring ptr)
declare function IupClassMatch(byval as Ihandle ptr, byval classname as const zstring ptr) as integer

declare function IupCreate (byval classname as const zstring ptr) as Ihandle ptr
declare function IupCreatev(byval classname as const zstring ptr, byval params as any ptr ptr) as Ihandle ptr
declare function IupCreatep(byval classname as const zstring ptr, byval first  as any ptr, ...) as Ihandle ptr

/'**********************************************************************'/
/'                        Elements                                      '/
/'**********************************************************************'/

declare function IupFill        as Ihandle ptr
declare function IupRadio      (byval child as Ihandle ptr) as Ihandle ptr
declare function IupVbox       (byval child as Ihandle ptr, ...) as Ihandle ptr
declare function IupVboxv      (byval children as Ihandle ptr ptr) as Ihandle ptr
declare function IupZbox       (byval child as Ihandle ptr, ...) as Ihandle ptr
declare function IupZboxv      (byval children as Ihandle ptr ptr) as Ihandle ptr
declare function IupHbox       (byval child as Ihandle ptr,...) as Ihandle ptr
declare function IupHboxv      (byval children as Ihandle ptr ptr) as Ihandle ptr

declare function IupNormalizer (byval first as Ihandle ptr, ...) as Ihandle ptr
declare function IupNormalizerv(byval list as Ihandle ptr ptr) as Ihandle ptr

declare function IupCbox       (byval child as Ihandle ptr, ...) as Ihandle ptr
declare function IupCboxv      (byval children as Ihandle ptr ptr) as Ihandle ptr
declare function IupSbox       (byval child as Ihandle ptr) as Ihandle ptr
declare function IupSplit      (byval child1 as Ihandle ptr, byval child2 as Ihandle ptr) as Ihandle ptr
declare function IupScrollBox  (byval child as Ihandle ptr) as Ihandle ptr
declare function IupGridBox    (byval child as Ihandle ptr, ...) as Ihandle ptr
declare function IupGridBoxv   (byval children as Ihandle ptr ptr) as Ihandle ptr
declare function IupExpander   (byval child as Ihandle ptr) as Ihandle ptr
declare function IupDetachBox  (byval child as Ihandle ptr) as Ihandle ptr
declare function IupBackgroundBox(byval child as Ihandle ptr) as Ihandle ptr

declare function IupFrame      (byval child as Ihandle ptr) as Ihandle ptr

declare function IupImage      (byval width as integer, byval height as integer, byval pixmap as const ubyte ptr) as Ihandle ptr
declare function IupImageRGB   (byval width as integer, byval height as integer, byval pixmap as const ubyte ptr) as Ihandle ptr
declare function IupImageRGBA  (byval width as integer, byval height as integer, byval pixmap as const ubyte ptr) as Ihandle ptr

declare function IupItem       (byval title as const zstring ptr, byval action as const zstring ptr) as Ihandle ptr
declare function IupSubmenu    (byval title as const zstring ptr, byval child as Ihandle ptr) as Ihandle ptr
declare function IupSeparator  as Ihandle ptr
declare function IupMenu       (byval child as Ihandle ptr,...) as Ihandle ptr
declare function IupMenuv      (byval chldren as Ihandle ptr ptr) as Ihandle ptr

declare function IupButton     (byval title as const zstring ptr, byval action as const zstring ptr) as Ihandle ptr
declare function IupCanvas     (byval action as const zstring ptr) as Ihandle ptr
declare function IupDialog     (byval child as Ihandle ptr) as Ihandle ptr
declare function IupUser        as Ihandle ptr
declare function IupLabel      (byval title as const zstring ptr) as Ihandle ptr
declare function IupList       (byval action as const zstring ptr) as Ihandle ptr
declare function IupText       (byval action as const zstring ptr) as Ihandle ptr
declare function IupMultiLine  (byval action as const zstring ptr) as Ihandle ptr
declare function IupToggle     (byval title as const zstring ptr, byval action as const zstring ptr) as Ihandle ptr
declare function IupTimer       as Ihandle ptr
declare function IupClipboard   as Ihandle ptr
declare function IupProgressBar as Ihandle ptr
declare function IupVal        (byval type as const zstring ptr) as Ihandle ptr
declare function IupTabs       (byval child as Ihandle ptr, ...) as Ihandle ptr
declare function IupTabsv      (byval children as Ihandle ptr ptr) as Ihandle ptr
declare function IupTree       as Ihandle ptr
declare function IupLink       (byval url as const zstring ptr, byval title as const zstring ptr) as Ihandle ptr

/' Old controls, use SPIN attribute of IupText '/
declare function IupSpin        as Ihandle ptr
declare function IupSpinbox    (byval child as Ihandle ptr) as Ihandle ptr

/'**********************************************************************'/
/'                      Utilities                                       '/
/'**********************************************************************'/

/' IupImage utility '/
declare function IupSaveImageAsText(byval as Ihandle ptr, byval filename as const zstring ptr, byval format as const zstring ptr, byval name as const zstring ptr) as integer

/' IupText and IupScintilla utilities '/
declare sub      IupTextConvertLinColToPos(byval as Ihandle ptr, byval lin as integer, byval col as integer, byval pos as integer ptr)
declare sub      IupTextConvertPosToLinCol(byval as Ihandle ptr, byval pos as integer, byval lin as integer ptr, byval col as integer ptr)

/' IupText, IupList, IupTree, IupMatrix and IupScintilla utility '/
declare function IupConvertXYToPos(byval as Ihandle ptr, byval x as integer, byval y as integer) as integer

/' OLD names, kept for backward compatibility, will never be removed. '/
declare sub      IupStoreGlobal(byval name as const zstring ptr, byval value as const zstring ptr)
declare sub      IupStoreAttribute(byval as Ihandle ptr, byval name as const zstring ptr, byval value as const zstring ptr)
declare sub      IupSetfAttribute(byval as Ihandle ptr, byval name as const zstring ptr, byval format as const zstring ptr, ...)
declare sub      IupStoreAttributeId(byval as Ihandle ptr, byval name as const zstring ptr, byval id as integer, byval value as const zstring ptr)
declare sub      IupSetfAttributeId(byval as Ihandle ptr, byval name as const zstring ptr, byval id as integer, byval f as const zstring ptr, ...)
declare sub      IupStoreAttributeId2(byval as Ihandle ptr, byval name as const zstring ptr, byval lin as integer, byval col as integer, byval value as const zstring ptr)
declare sub      IupSetfAttributeId2(byval as Ihandle ptr, byval name as const zstring ptr, byval lin as integer, byval col as integer, byval format as const zstring ptr, ...)

/' IupTree utilities '/
declare function IupTreeSetUserId(byval as Ihandle ptr, byval id as integer, byval userid as any ptr) as integer
declare function IupTreeGetUserId(byval as Ihandle ptr, byval id as integer) as any ptr
declare function IupTreeGetId(byval as Ihandle ptr, byval userid as any ptr) as integer
declare sub      IupTreeSetAttributeHandle(byval as Ihandle ptr, byval name as const zstring ptr, byval id as integer, byval ih_named as Ihandle ptr)

/' DEPRECATED IupTree utilities, use Iup*AttributeId functions. It will be removed in a future version.  '/
declare sub      IupTreeSetAttribute  (byval as Ihandle ptr, byval name as const zstring ptr,byval id as integer, byval value as const zstring ptr)
declare sub      IupTreeStoreAttribute(byval as Ihandle ptr, byval name as const zstring ptr,byval id as integer, byval value as const zstring ptr)
declare function IupTreeGetAttribute  (byval as Ihandle ptr, byval name as const zstring ptr,byval id as integer) as zstring ptr
declare function IupTreeGetInt        (byval as Ihandle ptr, byval name as const zstring ptr,byval id as integer) as integer
declare function IupTreeGetFloat      (byval as Ihandle ptr, byval name as const zstring ptr,byval id as integer) as single
declare sub      IupTreeSetfAttribute (byval as Ihandle ptr, byval name as const zstring ptr,byval id as integer, byval format as const zstring ptr, ...)

/' DEPRECATED callback management. It will be removed in a future version. '/
declare function IupGetActionName as const zstring ptr

/' DEPRECATED font names. It will be removed in a future version.  '/
declare function IupMapFont       (byval iupfont as const zstring ptr) as zstring ptr
declare function IupUnMapFont     (byval driverfont as const zstring ptr) as zstring ptr


/'**********************************************************************'/
/'                      Pre-definided dialogs                           '/
/'**********************************************************************'/

declare function IupFileDlg as Ihandle ptr
declare function IupMessageDlg as Ihandle ptr
declare function IupColorDlg as Ihandle ptr
declare function IupFontDlg as Ihandle ptr
declare function IupProgressDlg as Ihandle ptr

declare function IupGetFile(byval arq as zstring ptr) as integer
declare sub      IupMessage(byval title as const zstring ptr, byval msg as const zstring ptr)
declare sub      IupMessagef(byval title as const zstring ptr, byval format as const zstring ptr, ...)
declare function IupAlarm(byval title as const zstring ptr, byval msg as const zstring ptr, byval b1 as const zstring ptr, byval b2 as const zstring ptr, byval b3 as const zstring ptr) as integer
declare function IupScanf(byval format as const zstring ptr, ...) as integer
declare function IupListDialog(byval type as integer, byval title as const zstring ptr, byval size as integer, byval list as const zstring ptr ptr, byval op as integer, byval max_col as integer, byval max_lin as integer, byval marks as integer ptr) as integer
declare function IupGetText(byval title as const zstring ptr, byval text as zstring ptr) as integer
declare function IupGetColor(byval x as integer, byval y as integer, byval r as ubyte ptr, byval g as ubyte ptr, byval b as ubyte ptr) as integer

type Iparamcb as function (byval dialog as Ihandle ptr, byval param_index as integer, byval user_data as any ptr) as integer
declare function IupGetParam(byval title as const zstring ptr, byval action as Iparamcb, byval user_data as any ptr, byval format as const zstring ptr,...) as integer
declare function IupGetParamv(byval title as const zstring ptr, byval action as Iparamcb, byval user_data as any ptr, byval format as const zstring ptr, byval param_count as integer, byval param_extra as integer, byval param_data as any ptr ptr) as integer

declare function IupLayoutDialog(byval dialog as Ihandle ptr) as Ihandle ptr
declare function IupElementPropertiesDialog(byval elem as Ihandle ptr) as Ihandle ptr

end extern

/'**********************************************************************'/
/'                   Common Flags and Return Values                     '/
/'**********************************************************************'/
#define IUP_ERROR     1
#define IUP_NOERROR   0
#define IUP_OPENED   -1
#define IUP_INVALID  -1
#define IUP_INVALID_ID -10

/'**********************************************************************'/
/'                   Callback Return Values                             '/
/'**********************************************************************'/
#define IUP_IGNORE    -1
#define IUP_DEFAULT   -2
#define IUP_CLOSE     -3
#define IUP_CONTINUE  -4

/'**********************************************************************'/
/'           IupPopup and IupShowXY Parameter Values                    '/
/'**********************************************************************'/
#define IUP_CENTER        &HFFFF  /' 65535 '/
#define IUP_LEFT          &HFFFE  /' 65534 '/
#define IUP_RIGHT         &HFFFD  /' 65533 '/
#define IUP_MOUSEPOS      &HFFFC  /' 65532 '/
#define IUP_CURRENT       &HFFFB  /' 65531 '/
#define IUP_CENTERPARENT  &HFFFA  /' 65530 '/
#define IUP_TOP       IUP_LEFT
#define IUP_BOTTOM    IUP_RIGHT

/'**********************************************************************'/
/'               SHOW_CB Callback Values                                '/
/'**********************************************************************'/
enum 
  IUP_SHOW
  IUP_RESTORE
  IUP_MINIMIZE
  IUP_MAXIMIZE
  IUP_HIDE
end enum

/'**********************************************************************'/
/'               SCROLL_CB Callback Values                              '/
/'**********************************************************************'/
enum
  IUP_SBUP
  IUP_SBDN
  IUP_SBPGUP
  IUP_SBPGDN
  IUP_SBPOSV
  IUP_SBDRAGV
  IUP_SBLEFT
  IUP_SBRIGHT
  IUP_SBPGLEFT
  IUP_SBPGRIGHT
  IUP_SBPOSH
  IUP_SBDRAGH
end enum

/'**********************************************************************'/
/'               Mouse Button Values and Macros                         '/
/'**********************************************************************'/
#define IUP_BUTTON1 asc("1")
#define IUP_BUTTON2 asc("2")
#define IUP_BUTTON3 asc("3")
#define IUP_BUTTON4 asc("4")
#define IUP_BUTTON5 asc("5")

#define iup_isshift(_s)   (_s[0]=asc("S"))
#define iup_iscontrol(_s) (_s[1]=asc("C"))
#define iup_isbutton1(_s) (_s[2]=asc("1"))
#define iup_isbutton2(_s) (_s[3]=asc("2"))
#define iup_isbutton3(_s) (_s[4]=asc("3"))
#define iup_isdouble(_s)  (_s[5]=asc("D"))
#define iup_isalt(_s)     (_s[6]=asc("A"))
#define iup_issys(_s)     (_s[7]=asc("Y"))
#define iup_isbutton4(_s) (_s[8]=asc("4"))
#define iup_isbutton5(_s) (_s[9]=asc("5"))

/' Old definitions for backward compatibility '/
#define isshift   iup_isshift
#define iscontrol iup_iscontrol
#define isbutton1 iup_isbutton1
#define isbutton2 iup_isbutton2
#define isbutton3 iup_isbutton3
#define isdouble  iup_isdouble
#define isalt     iup_isalt
#define issys     iup_issys
#define isbutton4 iup_isbutton4
#define isbutton5 iup_isbutton5


/'**********************************************************************'/
/'                      Pre-Defined Masks                               '/
/'**********************************************************************'/
#define IUP_MASK_FLOAT  "[+/-]?(/d+/.?/d*|/./d+)"
#define IUP_MASK_UFLOAT "(/d+/.?/d*|/./d+)"
#define IUP_MASK_EFLOAT "[+/-]?(/d+/.?/d*|/./d+)([eE][+/-]?/d+)?"
#define IUP_MASK_INT    "[+/-]?/d+"
#define IUP_MASK_UINT   "/d+"

/' Old definitions for backward compatibility '/
#define IUPMASK_FLOAT     IUP_MASK_FLOAT
#define IUPMASK_UFLOAT    IUP_MASK_UFLOAT
#define IUPMASK_EFLOAT    IUP_MASK_EFLOAT
#define IUPMASK_INT	      IUP_MASK_INT
#define IUPMASK_UINT      IUP_MASK_UINT


/'**********************************************************************'/
/'                   IupGetParam Callback situations                    '/
/'**********************************************************************'/
#define IUP_GETPARAM_OK     -1
#define IUP_GETPARAM_INIT   -2
#define IUP_GETPARAM_CANCEL -3
#define IUP_GETPARAM_HELP   -4


/'**********************************************************************'/
/'                   Record Input Modes                                 '/
/'**********************************************************************'/
enum 
  IUP_RECBINARY
  IUP_RECTEXT
end enum

/'*****************************************************************************
* Copyright (C) 1994-2014 Tecgraf, PUC-Rio.
*
* Permission is hereby granted, free of charge, to any person obtaining
* a copy of this software and associated documentation files (the
* "Software"), to deal in the Software without restriction, including
* without limitation the rights to use, copy, modify, merge, publish,
* distribute, sublicense, and/or sell copies of the Software, and to
* permit persons to whom the Software is furnished to do so, subject to
* the following conditions:
*
* The above copyright notice and this permission notice shall be
* included in all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
* EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
* TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
* SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*****************************************************************************'/

#endif ' __IUP_BI

